@@ -6,7 +6,7 @@ from typing import Union
 
 import pandas as pd
 
-from zvt.api.kdata import get_kdata_schema
+from zvt.api.kdata import get_kdata_schema, default_adjust_type
 from zvt.api.utils import get_recent_report_date
 from zvt.contract import Mixin, AdjustType
 from zvt.contract.api import decode_entity_id, get_entity_schema, get_entity_ids
@@ -46,15 +46,16 @@ def got_top_performance_by_month(entity_type='stock',
 
 def get_top_performance_entities(entity_type='stock', start_timestamp=None, end_timestamp=None, pct=0.1,
                                  return_type=None, adjust_type: Union[AdjustType, str] = None, filters=None,
-                                 show_name=False, list_days=None):
-    if not adjust_type and entity_type == 'stock':
-        adjust_type = AdjustType.hfq
+                                 show_name=False, list_days=None, entity_provider=None, data_provider=None):
+    if not adjust_type:
+        adjust_type = default_adjust_type(entity_type=entity_type)
     data_schema = get_kdata_schema(entity_type=entity_type, adjust_type=adjust_type)
 
     if list_days:
         entity_schema = get_entity_schema(entity_type=entity_type)
         list_date = next_date(start_timestamp, -list_days)
-        ignore_entities = get_entity_ids(entity_type=entity_type, filters=[entity_schema.list_date >= list_date])
+        ignore_entities = get_entity_ids(provider=entity_provider, entity_type=entity_type,
+                                         filters=[entity_schema.list_date >= list_date])
         if ignore_entities:
             logger.info(f'ignore size: {len(ignore_entities)}')
             logger.info(f'ignore entities: {ignore_entities}')
@@ -66,7 +67,7 @@ def get_top_performance_entities(entity_type='stock', start_timestamp=None, end_
 
     return get_top_entities(data_schema=data_schema, start_timestamp=start_timestamp, end_timestamp=end_timestamp,
                             column='close', pct=pct, method=WindowMethod.change, return_type=return_type,
-                            filters=filters, show_name=show_name)
+                            filters=filters, show_name=show_name, data_provider=data_provider)
 
 
 def get_top_fund_holding_stocks(timestamp=None, pct=0.3, by=None):
@@ -115,23 +116,29 @@ def get_top_fund_holding_stocks(timestamp=None, pct=0.3, by=None):
     return s.to_frame()
 
 
-def get_performance(entity_ids, start_timestamp=None, end_timestamp=None, adjust_type: Union[AdjustType, str] = None):
+def get_performance(entity_ids,
+                    start_timestamp=None,
+                    end_timestamp=None,
+                    adjust_type: Union[AdjustType, str] = None,
+                    data_provider=None):
     entity_type, _, _ = decode_entity_id(entity_ids[0])
-    if not adjust_type and entity_type == 'stock':
-        adjust_type = AdjustType.hfq
+    if not adjust_type:
+        adjust_type = default_adjust_type(entity_type=entity_type)
     data_schema = get_kdata_schema(entity_type=entity_type, adjust_type=adjust_type)
 
     result, _ = get_top_entities(data_schema=data_schema, column='close', start_timestamp=start_timestamp,
                                  end_timestamp=end_timestamp, pct=1, method=WindowMethod.change,
-                                 return_type=TopType.positive, filters=[data_schema.entity_id.in_(entity_ids)])
+                                 return_type=TopType.positive, filters=[data_schema.entity_id.in_(entity_ids)],
+                                 data_provider=data_provider)
     return result
 
 
 def get_top_volume_entities(entity_type='stock', entity_ids=None, start_timestamp=None, end_timestamp=None, pct=0.1,
                             return_type=TopType.positive, adjust_type: Union[AdjustType, str] = None,
-                            method=WindowMethod.avg):
-    if not adjust_type and entity_type == 'stock':
-        adjust_type = AdjustType.hfq
+                            method=WindowMethod.avg, data_provider=None):
+    if not adjust_type:
+        adjust_type = default_adjust_type(entity_type=entity_type)
+
     data_schema = get_kdata_schema(entity_type=entity_type, adjust_type=adjust_type)
 
     filters = None
@@ -139,13 +146,14 @@ def get_top_volume_entities(entity_type='stock', entity_ids=None, start_timestam
         filters = [data_schema.entity_id.in_(entity_ids)]
 
     result, _ = get_top_entities(data_schema=data_schema, start_timestamp=start_timestamp, end_timestamp=end_timestamp,
-                                 column='turnover', pct=pct, method=method, return_type=return_type, filters=filters)
+                                 column='turnover', pct=pct, method=method, return_type=return_type, filters=filters,
+                                 data_provider=data_provider)
     return result
 
 
 def get_top_entities(data_schema: Mixin, column: str, start_timestamp=None, end_timestamp=None, pct=0.1,
                      method: WindowMethod = WindowMethod.change, return_type: TopType = None, filters=None,
-                     show_name=False):
+                     show_name=False, data_provider=None):
     """
     get top entities in specific domain between time range
 
@@ -172,7 +180,7 @@ def get_top_entities(data_schema: Mixin, column: str, start_timestamp=None, end_
         columns = ['entity_id', column]
 
     all_df = data_schema.query_data(start_timestamp=start_timestamp, end_timestamp=end_timestamp,
-                                    columns=columns, filters=filters)
+                                    columns=columns, filters=filters, provider=data_provider)
     if not pd_is_not_null(all_df):
         return None, None
     g = all_df.groupby('entity_id')
@@ -268,4 +276,6 @@ if __name__ == '__main__':
             #     TechnicalFactor(entity_ids=[entity_id], end_timestamp=end_date).draw(show=True)
 
 # the __all__ is generated
-__all__ = ['WindowMethod', 'TopType', 'got_top_performance_by_month', 'get_top_performance_entities', 'get_top_fund_holding_stocks', 'get_performance', 'get_top_volume_entities', 'get_top_entities', 'show_month_performance', 'show_industry_composition']
\ No newline at end of file
+__all__ = ['WindowMethod', 'TopType', 'got_top_performance_by_month', 'get_top_performance_entities',
+           'get_top_fund_holding_stocks', 'get_performance', 'get_top_volume_entities', 'get_top_entities',
+           'show_month_performance', 'show_industry_composition']
