@@ -1,16 +1,16 @@
 import operator
 from enum import Enum
 from itertools import accumulate
-from typing import List
+from typing import List, Optional
 
 import pandas as pd
 from pandas import DataFrame
 
 from zvt.contract import IntervalLevel
 from zvt.contract.drawer import Drawer
-from zvt.contract.factor import FilterFactor, ScoreFactor, Factor
+from zvt.contract.factor import Factor
 from zvt.domain.meta.stock_meta import Stock
-from zvt.utils.pd_utils import index_df, pd_is_not_null
+from zvt.utils.pd_utils import index_df, pd_is_not_null, is_filter_result_df, is_score_result_df
 from zvt.utils.time_utils import to_pd_timestamp, now_pd_timestamp
 
 
@@ -19,7 +19,8 @@ class TargetType(Enum):
     open_long = 'open_long'
     # open_short 代表开空，并应该平掉相应标的的多单
     open_short = 'open_short'
-    # 其他情况就是保持当前的持仓
+    # keep 代表保持现状，跟主动开仓有区别，有时有仓位是可以保持的，但不适合开新的仓
+    keep = 'keep'
 
 
 class SelectMode(Enum):
@@ -49,13 +50,13 @@ class TargetSelector(object):
         self.short_threshold = short_threshold
         self.level = level
 
-        self.filter_factors: List[FilterFactor] = []
-        self.score_factors: List[ScoreFactor] = []
+        self.factors: List[Factor] = []
         self.filter_result = None
         self.score_result = None
 
-        self.open_long_df: DataFrame = None
-        self.open_short_df: DataFrame = None
+        self.open_long_df: Optional[DataFrame] = None
+        self.open_short_df: Optional[DataFrame] = None
+        self.keep_df: Optional[DataFrame] = None
 
         self.init_factors(entity_ids=entity_ids, entity_schema=entity_schema, exchanges=exchanges, codes=codes,
                           start_timestamp=start_timestamp, end_timestamp=end_timestamp, level=self.level)
@@ -63,25 +64,17 @@ class TargetSelector(object):
     def init_factors(self, entity_ids, entity_schema, exchanges, codes, start_timestamp, end_timestamp, level):
         pass
 
-    def add_filter_factor(self, factor: FilterFactor):
+    def add_factor(self, factor: Factor):
         self.check_factor(factor)
-        self.filter_factors.append(factor)
-        return self
-
-    def add_score_factor(self, factor: ScoreFactor):
-        self.check_factor(factor)
-        self.score_factors.append(factor)
+        self.factors.append(factor)
         return self
 
     def check_factor(self, factor: Factor):
         assert factor.level == self.level
 
     def move_on(self, to_timestamp=None, kdata_use_begin_time=False, timeout=20):
-        if self.score_factors:
-            for factor in self.score_factors:
-                factor.move_on(to_timestamp, timeout=timeout)
-        if self.filter_factors:
-            for factor in self.filter_factors:
+        if self.factors:
+            for factor in self.factors:
                 factor.move_on(to_timestamp, timeout=timeout)
 
         self.run()
@@ -90,49 +83,45 @@ class TargetSelector(object):
         """
 
         """
-        if self.filter_factors:
-            musts = []
-            for factor in self.filter_factors:
-                df = factor.result_df
-
-                if not pd_is_not_null(df):
-                    raise Exception('no data for factor:{},{}'.format(factor.factor_name, factor))
-
-                if len(df.columns) > 1:
-                    s = df.agg("and", axis="columns")
-                    s.name = 'score'
-                    musts.append(s.to_frame(name='score'))
-                else:
-                    df.columns = ['score']
-                    musts.append(df)
-
-            if self.select_mode == SelectMode.condition_and:
-                self.filter_result = list(accumulate(musts, func=operator.__and__))[-1]
-            else:
-                self.filter_result = list(accumulate(musts, func=operator.__or__))[-1]
-        if self.score_factors:
+        if self.factors:
+            filters = []
             scores = []
-            for factor in self.score_factors:
-                df = factor.result_df
-                if not pd_is_not_null(df):
-                    raise Exception('no data for factor:{},{}'.format(factor.factor_name, factor))
+            for factor in self.factors:
+                if is_filter_result_df(factor.result_df):
+                    df = factor.result_df[['filter_result']]
+                    if pd_is_not_null(df):
+                        df.columns = ['score']
+                        filters.append(df)
+                    else:
+                        raise Exception('no data for factor:{},{}'.format(factor.factor_name, factor))
+                if is_score_result_df(factor.result_df):
+                    df = factor.result_df[['score_result']]
+                    if pd_is_not_null(df):
+                        df.columns = ['score']
+                        scores.append(df)
+                    else:
+                        raise Exception('no data for factor:{},{}'.format(factor.factor_name, factor))
 
-                if len(df.columns) > 1:
-                    s = df.agg("mean", axis="columns")
-                    s.name = 'score'
-                    scores.append(s.to_frame(name='score'))
+            if filters:
+                if self.select_mode == SelectMode.condition_and:
+                    self.filter_result = list(accumulate(filters, func=operator.__and__))[-1]
                 else:
-                    df.columns = ['score']
-                    scores.append(df)
-            self.score_result = list(accumulate(scores, func=operator.__add__))[-1]
+                    self.filter_result = list(accumulate(filters, func=operator.__or__))[-1]
+
+            if scores:
+                self.score_result = list(accumulate(scores, func=operator.__add__))[-1] / len(scores)
 
         self.generate_targets()
 
-    def get_targets(self, timestamp, target_type: TargetType = TargetType.open_long) -> pd.DataFrame:
+    def get_targets(self, timestamp, target_type: TargetType = TargetType.open_long) -> List[str]:
         if target_type == TargetType.open_long:
             df = self.open_long_df
-        if target_type == TargetType.open_short:
+        elif target_type == TargetType.open_short:
             df = self.open_short_df
+        elif target_type == TargetType.keep:
+            df = self.keep_df
+        else:
+            assert False
 
         if pd_is_not_null(df):
             if timestamp in df.index:
@@ -148,22 +137,36 @@ class TargetSelector(object):
 
     # overwrite it to generate targets
     def generate_targets(self):
-        if pd_is_not_null(self.filter_result) and pd_is_not_null(self.score_result):
-            # for long
-            result1 = self.filter_result[self.filter_result.score]
-            result2 = self.score_result[self.score_result.score >= self.long_threshold]
-            long_result = result2.loc[result1.index, :]
-            # for short
-            result1 = self.filter_result[~self.filter_result.score]
-            result2 = self.score_result[self.score_result.score <= self.short_threshold]
-            short_result = result2.loc[result1.index, :]
-        elif pd_is_not_null(self.score_result):
-            long_result = self.score_result[self.score_result.score >= self.long_threshold]
-            short_result = self.score_result[self.score_result.score <= self.short_threshold]
-        else:
-            long_result = self.filter_result[self.filter_result.score == True]
-            short_result = self.filter_result[self.filter_result.score == False]
+        keep_result = pd.DataFrame()
+        long_result = pd.DataFrame()
+        short_result = pd.DataFrame()
 
+        if pd_is_not_null(self.filter_result):
+            keep_result = self.filter_result[self.filter_result['score'].isna()]
+            long_result = self.filter_result[self.filter_result['score'] == True]
+            short_result = self.filter_result[self.filter_result['score'] == False]
+
+        if pd_is_not_null(self.score_result):
+            score_keep_result = self.score_result[(self.score_result['score'] > self.short_threshold) & (
+                    self.score_result['score'] < self.long_threshold)]
+            if pd_is_not_null(keep_result):
+                keep_result = score_keep_result.loc[keep_result.index, :]
+            else:
+                keep_result = score_keep_result
+
+            score_long_result = self.score_result[self.score_result['score'] >= self.long_threshold]
+            if pd_is_not_null(long_result):
+                long_result = score_long_result.loc[long_result.index, :]
+            else:
+                long_result = score_long_result
+
+            score_short_result = self.score_result[self.score_result['score'] <= self.short_threshold]
+            if pd_is_not_null(short_result):
+                short_result = score_short_result.loc[short_result.index, :]
+            else:
+                short_result = score_short_result
+
+        self.keep_df = self.normalize_result_df(keep_result)
         self.open_long_df = self.normalize_result_df(long_result)
         self.open_short_df = self.normalize_result_df(short_result)
 
@@ -203,4 +206,4 @@ class TargetSelector(object):
 
 
 # the __all__ is generated
-__all__ = ['TargetType', 'SelectMode', 'TargetSelector']
\ No newline at end of file
+__all__ = ['TargetType', 'SelectMode', 'TargetSelector']
